/* eslint-disable jsx-a11y/no-static-element-interactions */
/* eslint-disable jsx-a11y/click-events-have-key-events */
/* eslint-disable react/no-array-index-key */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import './styles.css';

class DurationPicker extends Component {
	constructor(props) {
		super(props);
		this.state = {
			activeIndex: 0,
			buttonsDurations: [
				{ isActive: true, value: 30 },
				{ isActive: false, value: 60 },
				{ isActive: false, value: 90 },
				{ isActive: false, value: '', isCustomField: true }
			]
		};
	}

	onFieldChange = e => {
		const { value } = e.target;
		const { activeIndex, buttonsDurations } = this.state;

		if (e.target.validity.valid && value < 720) {
			buttonsDurations[activeIndex].value = value;
			this.setState({
				buttonsDurations,
				activeIndex: 3
			});
		}
	};

	onFieldClick = e => {
		const { activeIndex, buttonsDurations } = this.state;

		const newDurationButtons = JSON.parse(JSON.stringify(buttonsDurations));
		newDurationButtons[3].isActive = true;
		newDurationButtons[activeIndex].isActive = false;
		e.currentTarget.querySelector('input').focus();
		this.setState({
			buttonsDurations: newDurationButtons,
			activeIndex: 3
		});
	};

	setActive = (value, index) => {
		const { buttonsDurations, activeIndex } = this.state;
		buttonsDurations[activeIndex].isActive = false;
		buttonsDurations[index].isActive = true;

		this.setState({
			buttonsDurations,
			activeIndex: index
		});
	};

	handleAddTime = async () => {
		if (this.isSubmitDisabled()) return;
		const { buttonsDurations, activeIndex } = this.state;
		const selectedDuration = parseInt(buttonsDurations[activeIndex].value);
		await this.props.handleFocusMode(selectedDuration);
	};

	isSubmitDisabled = () => {
		const { buttonsDurations, activeIndex } = this.state;
		return (
			buttonsDurations[activeIndex].isActive &&
			buttonsDurations[activeIndex].isCustomField &&
			buttonsDurations[activeIndex].value === ''
		);
	};

	render() {
		const { buttonsDurations, activeIndex } = this.state;
		const { cancelHandler } = this.props;
		const submitDisabled = this.isSubmitDisabled();

		return (
			<div className="focus-duration-menu">
				<div className="focus-mode-header">Start your focus mode</div>
				<div className="duration-buttons-wrapper">
					{buttonsDurations.map((button, index) => {
						if (!button.isCustomField) {
							const isSelected = button.isActive
								? 'selected'
								: '';
							return (
								<div
									key={index}
									className={`duration-btn ${isSelected}`}
									value={button.value}
									onClick={() =>
										this.setActive(button.value, index)
									}
								>
									<div
										className={`timer icon-timer-${button.value}`}
									/>
									<span>{button.value} min</span>
								</div>
							);
						}

						let customSelectClasses = button.isActive
							? 'selected '
							: '';
						customSelectClasses +=
							buttonsDurations[activeIndex].value !== '' &&
							buttonsDurations[activeIndex].isCustomField
								? 'custom-duration-active'
								: '';
						return (
							<div
								key={index}
								className={`custom-duration-wrapper ${customSelectClasses}`}
							>
								<div
									className="duration-btn"
									onClick={this.onFieldClick}
								>
									<input
										className="custom-time-input"
										placeholder="Custom time"
										value={
											buttonsDurations[activeIndex]
												.isCustomField &&
											buttonsDurations[activeIndex].value
										}
										onChange={this.onFieldChange}
										pattern="[0-9.]+"
										type="text"
									/>
									<div className="mins-label">min</div>
								</div>
							</div>
						);
					})}
				</div>

				<div className="focus-border-line-wrapper">
					<div className="focus-border-line" />
				</div>
				<div className="duration-picker-footer">
					<div
						className={`focus-start-button ${
							submitDisabled ? 'disabled' : ''
						}`}
						onClick={this.handleAddTime}
					>
						<span className="start-tittle">Add time</span>
					</div>
					<div className="cancel-btn" onClick={cancelHandler}>
						<span className="start-tittle">Cancel</span>
					</div>
				</div>
			</div>
		);
	}
}

DurationPicker.propTypes = {
	handleFocusMode: PropTypes.func.isRequired,
	cancelHandler: PropTypes.func.isRequired
};

export default DurationPicker;
