/* eslint-disable jsx-a11y/no-static-element-interactions */
/* eslint-disable jsx-a11y/click-events-have-key-events */
/* eslint-disable react/no-array-index-key */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import './styles.css';

class Starter extends Component {
	constructor(props) {
		super(props);
		this.state = {
			activeIndex: 0,
			submitDisabled: false,
			buttonsDurations: [
				{ isActive: false, value: 30 },
				{ isActive: false, value: 60 },
				{ isActive: false, value: 90 },
				{ isActive: false, value: '', isCustomField: true }
			]
		};
	}

	onFieldChange = e => {
		const { value } = e.target;

		if (e.target.validity.valid && value < 720) {
			let submitDisabled = false;
			if (value === '') {
				submitDisabled = true;
			}
			this.setState({
				submitDisabled
			});
			this.props.handleCustomTime(value);
		}
	};

	onFieldClick = e => {
		const { activeIndex, buttonsDurations } = this.state;

		const newDurationButtons = JSON.parse(JSON.stringify(buttonsDurations));
		newDurationButtons[3].isActive = true;
		newDurationButtons[activeIndex].isActive = false;
		e.currentTarget.querySelector('input').focus();
		this.setState({
			buttonsDurations: newDurationButtons,
			activeIndex: 3
		});
	};

	setActive = (value, index) => {
		const { buttonsDurations, activeIndex } = this.state;

		buttonsDurations[index].isActive = true;

		buttonsDurations[activeIndex].isActive = false;

		this.setState({
			buttonsDurations,
			activeIndex: index,
			submitDisabled: false
		});
		this.props.handleClick(value);
	};

	render() {
		const { value, handleFocusMode, customFocusDuration } = this.props;
		const { buttonsDurations, submitDisabled } = this.state;
		return (
			<div>
				<div className="focus-mode-header">Start your focus mode</div>
				<div className="duration-buttons-wrapper">
					{buttonsDurations.map((button, index) => {
						if (!button.isCustomField) {
							const isSelected =
								value === button.value ? 'selected' : '';
							return (
								<div
									key={index}
									className={`duration-btn ${isSelected}`}
									value={button.value}
									onClick={() =>
										this.setActive(button.value, index)
									}
								>
									<div
										className={`timer icon-timer-${button.value}`}
									/>
									<span>{button.value} min</span>
								</div>
							);
						}

						let customSelectClasses =
							customFocusDuration && customFocusDuration !== ''
								? 'selected '
								: '';
						customSelectClasses +=
							customFocusDuration !== ''
								? 'custom-duration-active'
								: '';
						return (
							<div
								key={index}
								className={`custom-duration-wrapper ${customSelectClasses}`}
							>
								<div
									className="duration-btn"
									onClick={e => this.onFieldClick(e)}
								>
									<input
										className="custom-time-input"
										value={customFocusDuration}
										placeholder="Custom time"
										onChange={this.onFieldChange}
										pattern="[0-9.]+"
										type="text"
									/>
									<div className="mins-label">min</div>
								</div>
							</div>
						);
					})}
				</div>

				<div className="focus-border-line-wrapper">
					<div className="focus-border-line" />
				</div>
				<div className="focus-start-button-wrapper">
					<div
						className={`focus-start-button ${
							submitDisabled ? 'disabled' : ''
						}`}
						onClick={() => handleFocusMode(true)}
					>
						<span className="start-tittle">Start Focus Mode</span>
						<div className="start-arrow" />
					</div>
				</div>
			</div>
		);
	}
}

Starter.propTypes = {
	value: PropTypes.number.isRequired,
	customFocusDuration: PropTypes.string.isRequired,
	handleClick: PropTypes.func.isRequired,
	handleFocusMode: PropTypes.func.isRequired,
	handleCustomTime: PropTypes.func.isRequired
};

export default Starter;
