/* eslint-disable jsx-a11y/click-events-have-key-events */
/* eslint-disable jsx-a11y/no-static-element-interactions */
import React, { Component } from 'react';
import PropTypes from 'prop-types';

class ToDoList extends Component {
	constructor(props) {
		super(props);
		this.state = {
			editedRowIndex: -1,
			editableValue: ''
		};
	}

	handleEditView = (editedRowIndex, editableValue) => {
		this.setState({ editedRowIndex, editableValue });
	};

	onFieldChange = e => {
		const { value } = e.target;
		this.setState({
			editableValue: value
		});
	};

	handleEditTodo = () => {
		const { editedRowIndex, editableValue } = this.state;

		this.props.editItem(editedRowIndex, editableValue);

		this.setState({ editedRowIndex: -1, editableValue: '' });
	};

	handleClearEdit = () => {
		this.setState({ editedRowIndex: -1, editableValue: '' });
	};

	handleOnKeyPress = e => {
		if (e.keyCode === 13) {
			this.handleEditTodo();
		}
		if (e.keyCode === 27) {
			this.handleClearEdit();
		}
	};

	render() {
		const { items, removeItem, checked, onClickItem } = this.props;

		const { editedRowIndex, editableValue } = this.state;
		return (
			<div>
				<div
					className={`todo-list-group ${
						checked ? 'checked-todos' : 'unchecked-todos'
					}`}
				>
					<ul>
						{items.map((item, index) => {
							return (
								<div key={index}>
									<li className="todo-list-group-item">
										{editedRowIndex === index ? (
											<div>
												<div className="to-do-unchecked-circle" />
												<input
													className="todo-edit-input"
													value={editableValue}
													placeholder="Custom time"
													onChange={
														this.onFieldChange
													}
													onKeyDown={
														this.handleOnKeyPress
													}
													autoFocus
												/>
												<div
													className="todo-done-icon"
													onClick={
														this.handleEditTodo
													}
												>
													<svg
														id="Layer_1"
														data-name="Layer 1"
														xmlns="http://www.w3.org/2000/svg"
														viewBox="0 0 24 24"
													>
														<title>done</title>
														<path d="M19.85,7.25,9.25,17.85a.5.5,0,0,1-.71,0L3.15,12.46a.5.5,0,0,1,0-.71l.7-.7a.5.5,0,0,1,.71,0l4.33,4.33,9.55-9.55a.51.51,0,0,1,.71,0l.7.71A.5.5,0,0,1,19.85,7.25Z" />
													</svg>
												</div>
												<div
													className="todo-clear-icon"
													onClick={
														this.handleClearEdit
													}
												>
													<svg
														id="Layer_1"
														data-name="Layer 1"
														xmlns="http://www.w3.org/2000/svg"
														viewBox="0 0 24 24"
													>
														<title>clear</title>
														<path d="M17.85,16.44a.5.5,0,0,1,0,.71l-.7.7a.5.5,0,0,1-.71,0L12,13.41,7.56,17.85a.5.5,0,0,1-.71,0l-.7-.7a.5.5,0,0,1,0-.71L10.59,12,6.15,7.56a.5.5,0,0,1,0-.71l.7-.7a.5.5,0,0,1,.71,0L12,10.59l4.44-4.44a.5.5,0,0,1,.71,0l.7.7a.5.5,0,0,1,0,.71L13.41,12Z" />
													</svg>
												</div>
											</div>
										) : (
											<div>
												<div
													onClick={
														!checked
															? () =>
																	onClickItem(
																		index
																	)
															: () => {}
													}
													className={`${
														checked
															? 'to-do-checked-circle'
															: 'to-do-unchecked-circle'
													}`}
												/>
												<div
													className="todo-name"
													onClick={
														!checked
															? () =>
																	this.handleEditView(
																		index,
																		item.value
																	)
															: () => {}
													}
												>
													{item.value}
												</div>
												{!checked && (
													<div
														className="todo-edit-icon"
														onClick={() =>
															this.handleEditView(
																index,
																item.value
															)
														}
													>
														<svg
															xmlns="http://www.w3.org/2000/svg"
															width="14.004"
															height={14}
															viewBox="0 0 14.004 14"
														>
															<path
																id="edit"
																d="M13.71,8.433a.388.388,0,0,1,0,.543l-6.256,6.28a1.552,1.552,0,0,1-.528.349L3.557,16.972a.388.388,0,0,1-.419-.085h0a.388.388,0,0,1-.147-.481l1.335-3.369a1.552,1.552,0,0,1,.349-.528l6.264-6.264a.388.388,0,0,1,.551,0Zm2.911-4.58-.512-.512A1.164,1.164,0,0,0,15.286,3H14.7a1.164,1.164,0,0,0-.838.342l-1.4,1.42a.388.388,0,0,0,0,.543l2.181,2.212a.388.388,0,0,0,.551,0L16.621,6.1a1.164,1.164,0,0,0,.342-.838v-.59A1.164,1.164,0,0,0,16.621,3.854Z"
																transform="translate(-2.959 -3)"
																fill="#959595"
															/>
														</svg>
													</div>
												)}
												<div
													onClick={() =>
														removeItem(index)
													}
													className="todo-delete-icon"
												>
													<svg
														xmlns="http://www.w3.org/2000/svg"
														width="12.8"
														height={16}
														viewBox="0 0 12.8 16"
													>
														<path
															id="delete"
															d="M16.8,4v.8a.4.4,0,0,1-.4.4H4.4A.4.4,0,0,1,4,4.8V4a.4.4,0,0,1,.4-.4H8V2.8A.8.8,0,0,1,8.8,2H12a.8.8,0,0,1,.8.8v.8h3.6A.4.4,0,0,1,16.8,4ZM5.5,16.512A1.6,1.6,0,0,0,7.1,18H13.72a1.6,1.6,0,0,0,1.6-1.488L16,6.8H4.8Z"
															transform="translate(-4 -2)"
															fill="#959595"
														/>
													</svg>
												</div>
											</div>
										)}
									</li>
								</div>
							);
						})}
					</ul>
				</div>
			</div>
		);
	}
}

ToDoList.propTypes = {
	removeItem: PropTypes.func.isRequired,
	items: PropTypes.array.isRequired,
	checked: PropTypes.bool,
	onClickItem: PropTypes.func.isRequired,
	editItem: PropTypes.func
};

export default ToDoList;
