import React, { Component } from 'react';
import PropTypes from 'prop-types';

import ToDoList from './ToDoList/index';
import ToDoForm from './ToDoForm/index';
import './styles.css';

class ToDos extends Component {
	addItem = toDoItem => {
		const { addTodo } = this.props;
		addTodo(toDoItem);
	};

	removeItem = itemIndex => {
		const { removeTodo } = this.props;
		removeTodo(itemIndex);
	};

	removeCheckedItem = itemIndex => {
		const { removeCheckedTodo } = this.props;
		removeCheckedTodo(itemIndex);
	};

	editItem = (itemIndex, itemValue) => {
		const { editTodo } = this.props;
		editTodo(itemIndex, itemValue);
	};

	render() {
		const {
			initItems,
			handleBlockSite,
			checkedTodos,
			doneTodo,
			unDoneTodo
		} = this.props;
		return (
			<div className="todos-wrapper">
				<div className="todos-header">To do</div>
				<div style={{ width: '100%' }}>
					<ToDoForm items={initItems} addItem={this.addItem} />
					<ToDoList
						items={initItems}
						removeItem={this.removeItem}
						handleBlockSite={handleBlockSite}
						onClickItem={doneTodo}
						editItem={this.editItem}
					/>
					<div className="todo-border-line" />
					<ToDoList
						items={checkedTodos}
						removeItem={this.removeCheckedItem}
						handleBlockSite={handleBlockSite}
						onClickItem={unDoneTodo}
						checked
					/>
				</div>
			</div>
		);
	}
}

ToDos.propTypes = {
	addTodo: PropTypes.func.isRequired,
	handleBlockSite: PropTypes.func.isRequired,
	initItems: PropTypes.array.isRequired,
	checkedTodos: PropTypes.array.isRequired,
	removeTodo: PropTypes.func.isRequired,
	removeCheckedTodo: PropTypes.func.isRequired,
	doneTodo: PropTypes.func.isRequired,
	unDoneTodo: PropTypes.func.isRequired,
	editTodo: PropTypes.func.isRequired
};

export default ToDos;
